#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unordered-containers
version: 0.2.7.0
id: unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
key: unord_2BLx4faR35mFWLJj5xiBgm
license: BSD3
copyright: 2010-2014 Johan Tibell
           2010 Edward Z. Yang
maintainer: johan.tibell@gmail.com
homepage: https://github.com/tibbe/unordered-containers
synopsis: Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.
    .
    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.
category: Data
author: Johan Tibell
exposed: True
exposed-modules:
    Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
hidden-modules: Data.HashMap.Array Data.HashMap.Base
                Data.HashMap.PopCount Data.HashMap.Unsafe Data.HashMap.UnsafeShift
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/unordered-containers-0.2.7.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/unordered-containers-0.2.7.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/unordered-containers-0.2.7.0
hs-libraries: HSunordered-containers-0.2.7.0-2BLx4faR35mFWLJj5xiBgm
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
haddock-interfaces: /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock
haddock-html: /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
